@@ -1,5 +1,6 @@
 """System Bridge: Update Sensors"""
 import asyncio
+
 from systembridgeshared.base import Base
 from systembridgeshared.common import make_key
 from systembridgeshared.const import (
@@ -45,13 +46,33 @@ class SensorsUpdate(Base):
         """Update Fan Sensors"""
         if data := self._sensors.fans():
             for key, value in data.items():
-                self._database.write("sensors", f"fans_{key}", value)
+                for item in value:
+                    for subkey, subvalue in item._asdict().items():
+                        self._database.write_sensor(
+                            "sensors",
+                            f"fans_{key}_{subkey}",
+                            subkey,
+                            subkey,
+                            key,
+                            key,
+                            subvalue,
+                        )
 
     async def update_temperatures(self) -> None:
         """Update Temperature Sensors"""
         if data := self._sensors.temperatures():
             for key, value in data.items():
-                self._database.write("sensors", f"temperatures_{key}", value)
+                for item in value:
+                    for subkey, subvalue in item._asdict().items():
+                        self._database.write_sensor(
+                            "sensors",
+                            f"temperatures_{key}_{subkey}",
+                            subkey,
+                            subkey,
+                            key,
+                            key,
+                            subvalue,
+                        )
 
     async def update_windows_sensors(self) -> None:
         """Update Windows Sensors"""
@@ -89,7 +110,7 @@ class SensorsUpdate(Base):
                         type_hardware = (
                             hardware["type"] if "type" in hardware else "NVIDIA"
                         )
-                        name_hardware = hardware["name"] if "name" in hardware else None
+                        name_hardware = hardware["name"] if "name" in hardware else ""
                         if "DISPLAY" in name_hardware:
                             type_hardware = "Display"
                             name_hardware = (
