@@ -1,4 +1,5 @@
 """System Bridge: WebSocket handler"""
+from collections.abc import Callable
 from json import JSONDecodeError, dumps, loads
 from uuid import uuid4
 
@@ -38,8 +39,8 @@ from systembridgeshared.const import (
     TYPE_GET_SETTINGS,
     TYPE_KEYBOARD_KEY_PRESSED,
     TYPE_KEYBOARD_KEYPRESS,
-    TYPE_KEYBOARD_TEXT_SENT,
     TYPE_KEYBOARD_TEXT,
+    TYPE_KEYBOARD_TEXT_SENT,
     TYPE_OPEN,
     TYPE_OPENED,
     TYPE_REGISTER_DATA_LISTENER,
@@ -68,7 +69,7 @@ class WebSocketHandler(Base):
         listeners: Listeners,
         implemented_modules: list[str],  # pylint: disable=unsubscriptable-object
         websocket,
-        callback_exit_application: callable,
+        callback_exit_application: Callable,
     ) -> None:
         """Initialize"""
         super().__init__()
@@ -175,7 +176,20 @@ class WebSocketHandler(Base):
                         )
                         continue
 
-                    keyboard_keypress(data["key"])
+                    try:
+                        keyboard_keypress(data["key"])
+                    except ValueError as err:
+                        self._logger.warning(err.args[0])
+                        await self._websocket.send(
+                            dumps(
+                                {
+                                    EVENT_TYPE: TYPE_ERROR,
+                                    EVENT_SUBTYPE: SUBTYPE_MISSING_KEY,
+                                    EVENT_MESSAGE: "Invalid key",
+                                }
+                            )
+                        )
+                        continue
 
                     await self._websocket.send(
                         dumps(
